@@ -7,13 +7,11 @@
 #ifndef EDITOR_H
 #define EDITOR_H
 
-#include "graphtheory_export.h"
 #include "graphdocument.h"
+#include "typenames.h"
+#include "graphtheory_export.h"
 #include <QObject>
 
-class QQuickWidget;
-class QQmlEngine;
-
 namespace GraphTheory
 {
 class EditorPrivate;
