@@ -5,13 +5,12 @@
  */
 
 #include "editorplugins/editorplugininterface.h"
-
-#include "graphdocument.h"
 #include "graphlayoutwidget.h"
 #include "logging_p.h"
 #include "typenames.h"
 #include <KPluginFactory>
 #include <QDialog>
+#include <QPointer>
 
 using namespace GraphTheory;
 
