@@ -8,11 +8,10 @@
 #include "dotgrammarhelper.h"
 #include "dotgrammar.h"
 #include "edge.h"
-#include "graphdocument.h"
 #include "logging_p.h"
 #include "node.h"
-
 #include <QFile>
+#include <QVariant>
 
 extern DotParser::DotGraphParsingHelper *phelper;
 
