@@ -12,7 +12,7 @@
 #include "kernel.h"
 #include "node.h"
 #include "typenames.h"
-
+#include <optional>
 #include <QColor>
 #include <QObject>
 
@@ -41,6 +41,14 @@ public:
 
     EdgePtr edge() const;
 
+    QJSValue toScriptValue(QJSEngine *engine);
+
+    /**
+     * retrieve dynamic property values from script value and release association
+     * @note QJSValue is owned by JS engine
+     */
+    void releaseScriptValue();
+
     /**
      * @return EdgeType::id of corresponding node
      */
@@ -63,14 +71,15 @@ public Q_SLOTS:
     void updateDynamicProperties();
 
 Q_SIGNALS:
-    void message(const QString &messageString, Kernel::MessageType type) const;
+    void message(const QString &messageString, GraphTheory::MessageType type) const;
     void colorChanged(const QColor &color);
     void typeChanged();
 
 private:
     Q_DISABLE_COPY(EdgeWrapper)
     const EdgePtr m_edge;
-    const DocumentWrapper *m_documentWrapper;
+    const DocumentWrapper *m_documentWrapper{nullptr};
+    std::optional<QJSValue> m_scriptValue;
 };
 }
 
