@@ -6,8 +6,8 @@
 
 #include "nodetypesdelegate.h"
 #include "libgraphtheory/dialogs/nodetypeproperties.h"
-#include "libgraphtheory/models/nodetypemodel.h"
 #include "libgraphtheory/nodetype.h"
+#include "libgraphtheory/org/kde/rocs/nodetypemodel.h"
 #include <KColorButton>
 #include <KLocalizedString>
 #include <QAbstractItemView>
@@ -69,7 +69,7 @@ QList<QWidget *> NodeTypesDelegate::createItemWidgets(const QModelIndex &index)
     return {colorButton, title, idLabel, propertiesButton};
 }
 
-void NodeTypesDelegate::updateItemWidgets(const QList<QWidget *> widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const
+void NodeTypesDelegate::updateItemWidgets(const QList<QWidget *> &widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const
 {
     // widgets:
     // ColorButton | Title | ID
